# HG changeset patch
# User Sherief N. Farouk
# Date 1257136364 18000
# Node ID aefcb26eb7cf86f2ff91fa50fb061ca9bccbc28b
# Parent  71add1febc9e080205e7677315214802ec330d2f
Added graceful failure in case of allocation failure while initializing a resampler object.

diff -r 71add1febc9e -r aefcb26eb7cf libspeex/resample.c
--- a/libspeex/resample.c	Sun Nov 01 22:42:29 2009 -0500
+++ b/libspeex/resample.c	Sun Nov 01 23:32:44 2009 -0500
@@ -731,6 +731,12 @@
       return NULL;
    }
    st = (SpeexResamplerState *)speex_alloc(sizeof(SpeexResamplerState));
+   if(st == NULL)
+   {
+       if(err)
+           *err = RESAMPLER_ERR_ALLOC_FAILED;
+       return NULL;
+   }
    st->initialised = 0;
    st->started = 0;
    st->in_rate = 0;
@@ -754,11 +760,24 @@
 #else
    st->buffer_size = 160;
 #endif
+
+   /* Initialize pointer members to NULL to support destroying partially-initialized resampler objects. */
+   st->last_sample = NULL;
+   st->magic_samples = NULL;
+   st->samp_frac_num = NULL;
    
    /* Per channel data */
    st->last_sample = (spx_int32_t*)speex_alloc(nb_channels*sizeof(int));
    st->magic_samples = (spx_uint32_t*)speex_alloc(nb_channels*sizeof(int));
    st->samp_frac_num = (spx_uint32_t*)speex_alloc(nb_channels*sizeof(int));
+   /* If any of those allocations fail, destroy the partially-initialized object and return NULL. */
+   if((st->last_sample == NULL) || (st->magic_samples == NULL) || (st->samp_frac_num == NULL))
+   {
+       speex_resampler_destroy(st);
+       if(err)
+           *err = RESAMPLER_ERR_ALLOC_FAILED;
+       return NULL;
+   }
    for (i=0;i<nb_channels;i++)
    {
       st->last_sample[i] = 0;
